R/AllPairwiseAlign.R
AllPairwiseAlign.RdThis function is a wrapper function to compute all pairwise (global) alignments using VSEARCH.
AllPairwiseAlign( file, cores = 1, mask = "none", out.name = "AllPairwiseAlign", output = NULL )
| file | path to fasta file storing sequences for which all possible pairwise alignments shall be computed. |
|---|---|
| cores | number of cores that shall be used for parallel computations. |
| mask | shall the aligned sequences be maksed? Options are: |
| out.name | name of the output files ( |
| output | path to a folder in which output shall be stored. |
A folder named vsearch_pairwise_align will be created and the following files will be stored in this output folder:
*.uc USEARCH cluster format generated by VSEARCH storing the sequence cluster information of aligned sequences.
*_userout.txt a tab separated file storing the alignment information in the columns: query, target, sequence identity (ID).
*.blast6out BLAST output format of the pairwise (global) sequence alignments generated by VSEARCH.
*_fasta_pairs.fasta fasta file storing the alignments.
*.sam SAM file storing the alignments.
To be able to use this function the VSEARCH command line tool needs to be installed.
https://github.com/torognes/vsearch
Hajk-Georg Drost