Given a path to a folder that stores several LTRpred prediction files, this function imports the individual prediction files and combines them to one large LTRpred prediction file.
combinePreds(folder, quality.filter = FALSE, sim = 70, n.orfs = 0)
| folder | path to folder in which prediction files are stored. |
|---|---|
| quality.filter | shall false positives be filtered out as much as possible or not. |
| sim | If |
| n.orfs | If |
Hajk-Georg Drost