Repeat Masker filesR/meta.seq.space.R
meta.seq.space.RdThe repeat space for multiple Repeat Masker files is quantified and
stored in one tibble.
meta.seq.space( rm.folder, type = "rm", repeat.type = "all", rename = FALSE, save.file = TRUE )
| rm.folder | file path to the |
|---|---|
| type | type of input data. Option are:
|
| repeat.type | type of element for which total repeat space shall be quantified. Options are:
|
| rename | logical value indicating whether or not long file names shall be transformed to short scientific names. |
| save.file | logical value indicating whether or not the result |
Hajk-Georg Drost