R/pred2orfseqs.R
pred2orfseqs.RdThis function allows users to save the sequence of the predicted LTR Transposons or LTRs in a fasta file.
pred2orfseqs(LTRpred.tbl, orf.seq.file, output = "output.fa")
| LTRpred.tbl | the |
|---|---|
| orf.seq.file | the fasta file storing the open reading frame sequences of predicted retroelements.
as returned by the |
| output | the fasta file to which the output sequences shall be stored in. |
The output data.frames returned by LTRpred contain all information of the predicted
LTR retrotransposons that can be used for post-filtering steps. After these post-filtering steps
sequences of the remaining (filtered) candidates can be retrieved by this function.
Hajk-Georg Drost