R/rename.fasta.R
rename.fasta.RdReads a fasta file and adds the defined species name to each
header entry of the input fasta file.
rename.fasta(file, species, output = "renamed_fasta.fa", append = FALSE)
| file | input fasta file. |
|---|---|
| species | a character string specifying the species name to be added to the headers.
Format will be: |
| output | a character string denoting the name of the renamed output fasta file. |
| append | logical value. If |
Writes a new fasta file with renamed headers.
Hajk-Georg Drost